pub struct SliceHeader {
pub first_mb_in_slice: u32,
pub slice_type: u32,
pub pps_id: u32,
pub frame_num: u32,
pub field_pic_flag: bool,
pub bottom_field_flag: bool,
pub qp: i32,
}Expand description
Parsed slice header (subset of fields needed for IDR decoding).
Fields
first_mb_in_slice: u32slice_type: u32pps_id: u32frame_num: u32field_pic_flag: boolTrue when this slice is a single field (top or bottom) of an interlaced picture.
bottom_field_flag: boolWhen field_pic_flag is true, indicates this is the bottom field.
qp: i32Trait Implementations
Sourceimpl Clone for SliceHeader
impl Clone for SliceHeader
Sourcefn clone(&self) -> SliceHeader
fn clone(&self) -> SliceHeader
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for SliceHeader
impl RefUnwindSafe for SliceHeader
impl Send for SliceHeader
impl Sync for SliceHeader
impl Unpin for SliceHeader
impl UnsafeUnpin for SliceHeader
impl UnwindSafe for SliceHeader