pub struct Sps {Show 17 fields
pub profile_idc: u8,
pub level_idc: u8,
pub sps_id: u32,
pub chroma_format_idc: u32,
pub bit_depth_luma: u32,
pub bit_depth_chroma: u32,
pub log2_max_frame_num: u32,
pub pic_order_cnt_type: u32,
pub max_num_ref_frames: u32,
pub pic_width_in_mbs: u32,
pub pic_height_in_map_units: u32,
pub frame_mbs_only_flag: bool,
pub mb_adaptive_frame_field_flag: bool,
pub frame_crop_left: u32,
pub frame_crop_right: u32,
pub frame_crop_top: u32,
pub frame_crop_bottom: u32,
}Expand description
Parsed Sequence Parameter Set (subset of fields needed for frame dimensions).
Fields
profile_idc: u8level_idc: u8sps_id: u32chroma_format_idc: u32bit_depth_luma: u32bit_depth_chroma: u32log2_max_frame_num: u32pic_order_cnt_type: u32max_num_ref_frames: u32pic_width_in_mbs: u32pic_height_in_map_units: u32frame_mbs_only_flag: boolmb_adaptive_frame_field_flag: boolframe_crop_left: u32frame_crop_right: u32frame_crop_top: u32frame_crop_bottom: u32Implementations
Sourceimpl Sps
impl Sps
Sourcepub fn cropped_width(&self) -> usize
pub fn cropped_width(&self) -> usize
Cropped frame width.
Returns the full width if cropping would underflow (malformed SPS).
Sourcepub fn cropped_height(&self) -> usize
pub fn cropped_height(&self) -> usize
Cropped frame height.
Returns the full height if cropping would underflow (malformed SPS).